@@ -1,16 +1,16 @@
 from abc import ABC, abstractmethod
 
-from manafa.utils.Utils import execute_shell_command
+from manafa.utils.Utils import execute_shell_command, get_results_dir
 
-RESULTS_DIR="results/"
+RESULTS_DIR= get_results_dir()
 
 class Service(ABC):
 	"""docstring for Service"""
-	def __init__(self,results_dir=""):
-		self.results_dir = RESULTS_DIR + results_dir+"/"
+	def __init__(self, results_dir=""):
+		self.results_dir = RESULTS_DIR + "/" + results_dir+"/"
 
 	@abstractmethod
-	def config(self,**kwargs):
+	def config(self, **kwargs):
 		print(kwargs)
 
 	@abstractmethod
